@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ZephyrusSettings.py 12422 2020-07-23 14:22:03Z Lavender $
+# $Id: ZephyrusSettings.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-07-23 22:22:03 +0800 (週四, 23 七月 2020) $
-# $Revision: 12422 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -57,7 +57,7 @@ DATABASES = {
     }
 }
 
-LANGUAGE_CODE = 'zh-hant'
+LANGUAGE_CODE = 'en'
 
 TIME_ZONE = 'Asia/Taipei'
 
@@ -68,7 +68,7 @@ USE_L10N = True
 USE_TZ = True
 
 LANGUAGES = (
-    ('zh-hant', gettext('zh-hant')),
+    ('en', gettext('en')),
 )
 
 CMS_LANGUAGES = {
@@ -80,9 +80,9 @@ CMS_LANGUAGES = {
     1: [
         {
             'public': True,
-            'code': 'zh-hant',
+            'code': 'en',
             'hide_untranslated': False,
-            'name': gettext('zh-hant'),
+            'name': gettext('en'),
             'redirect_on_fallback': True,
         },
     ],
@@ -171,13 +171,8 @@ INSTALLED_APPS = (
     'filer',
     'easy_thumbnails',
     # 'cmsplugin_filer_image',
-    # 'cmsplugin_filer_file',
-    # 'cmsplugin_filer_folder',
-    # 'cmsplugin_filer_teaser',
-    # 'cmsplugin_filer_utils',
-    # 'cmsplugin_filer_video',
     'djangocms_googlemap',
-    'djangocms_inherit',
+    # 'djangocms_inherit',
     'djangocms_link',
     'djangocms_picture',
     
