@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12420 2020-07-23 08:06:48Z Lavender $
+# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-07-23 16:06:48 +0800 (週四, 23 七月 2020) $
-# $Revision: 12420 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import sys
@@ -97,9 +97,9 @@ def attachSettings(settingsDict):
         'Zephyrus.instagram',
         'Zephyrus.line',
         'Zephyrus.comment',
-        'Zephyrus.statistics',
-        'drip',
-        'Zephyrus.autoresponder',
+        'Zephyrus.stats',
+        # 'drip',
+        # 'Zephyrus.autoresponder',
         'robots',
         'django_gravatar',
         'captcha',
@@ -137,7 +137,7 @@ def attachSettings(settingsDict):
     #=========================================================================
     # Middleware
     middlewares = [
-        'Zephyrus.statistics.middleware.StatisticsMiddleware',
+        'Zephyrus.stats.middleware.StatisticsMiddleware',
     ]
    
     
